# with-cloud-blob

[![Build Status](https://travis-ci.org/kshpytsya/with-cloud-blob.svg?branch=master)](https://travis-ci.org/kshpytsya/with-cloud-blob)
[![Coverage Status](https://coveralls.io/repos/github/kshpytsya/with-cloud-blob/badge.svg?branch=master)](https://coveralls.io/github/kshpytsya/with-cloud-blob?branch=master)
[![Tests](https://report.ci/status/kshpytsya/with-cloud-blob/badge.svg?branch=master)](https://report.ci/status/kshpytsya/with-cloud-blob?branch=master)
